#
# spec file for package python-fastcluster
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-fastcluster
Version:        1.2.6
Release:        2.1
Summary:        Hierarchical clustering routines for Python
License:        BSD-2-Clause
URL:            https://github.com/dmuellner/fastcluster
Source:         https://files.pythonhosted.org/packages/source/f/fastcluster/fastcluster-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#fastcluster/fastcluster#94
Patch0:         support-numpy-2.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-scipy
%python_subpackages

%description
This library provides Python functions for hierarchical clustering.
It generates hierarchical clusters from distance matrices or from
vector data.

Part of this module is intended to replace the functions
linkage, single, complete, average, weighted, centroid, median, ward
in the module scipy.cluster.hierarchy with the same functionality but
much faster algorithms. Moreover, the function 'linkage_vector'
provides memory-efficient clustering for vector data.

The interface is very similar to MATLAB's Statistics Toolbox API to
make code easier to port from MATLAB to Python/Numpy. The core
implementation of this library is in C++ for efficiency.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module fastcluster-doc = %{version}}

%description -n %{name}-doc
Documentation and help files for %{name}.

%prep
%autosetup -p1 -n fastcluster-%{version}

sed -i 's/\r$//' CITATION.txt
sed -i 's/\r$//' NEWS.txt
sed -i 's/\r$//' README.txt

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF-8
%pyunittest_arch -v tests

%files %{python_files}
%license COPYING.txt
%doc CITATION.txt NEWS.txt README.txt
%{python_sitearch}/fastcluster.py
%{python_sitearch}/_fastcluster.cpython-*.so
%pycache_only %{python_sitearch}/__pycache__/fastcluster.*.pyc
%{python_sitearch}/fastcluster-%{version}.dist-info

%files -n %{name}-doc
%doc docs/fastcluster.pdf

%changelog
* Fri Jul 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-numpy-2.patch:
  * Support both numpy 1 and 2
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Wed Sep 28 2022 Arun Persaud <arun@gmx.de>
- update to version 1.2.6:
  * Move to GitHub action for CI. No code changes.
- changes from version 1.2.5:
  * Updated pyproject.toml to work with Python 3.10 and future Python
    versions.
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.4:
  * Documentation update.
  * Fixed #pragma in fastcluster.cpp.
  * Fixed NumPy versions in Travis builds.
* Sun May 23 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.2.0:
  - Dropped support for Python 2.
  - Python interface: Updated definition of the Yule distance
    function, following a change in SciPy 1.6.3.
* Sat May 22 2021 Matej Cepl <mcepl@suse.com>
- Add skip_error_test.patch removing the erroring test_vector
  test (gh#dmuellner/fastcluster#21).
* Fri May 14 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.1.28:
  - Replace deprecated “numpy.bool” and “numpy.int” by
    “bool” and “int”.
  - Updated NumPy dependency for Python 3.9.
* Tue Jan 19 2021 andy great <andythe_great@pm.me>
- Disable build for python36 because scipy dependency.
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- update to version 1.1.26:
  * Small updates for Python 3.8.
* Mon Sep 17 2018 Arun Persaud <arun@gmx.de>
- update to version 1.1.25:
  * Removed all “#pragma GCC diagnostic” directives in .cpp files due
    to changed CRAN requirements (CRAN repository only, not the GitHub
    repository).
* Wed Jul 18 2018 tchvatal@suse.com
- Stricten version requirements on numpy to >= 1.9
* Sat Nov  4 2017 arun@gmx.de
- update to version 1.1.24:
  * R 3.5 corrects the formula for the “Canberra” metric. See
    https://bugs.r-project.org/bugzilla/show_bug.cgi?id=17285.
    The formula in the fastcluster package was changed accordingly. This
    concerns only the R interface. SciPy and fastcluster's Python interface
    always had the correct formula.
* Thu May  4 2017 toddrme2178@gmail.com
- Update to Version 1.1.23
  * setup.py: Late NumPy import for better dependency management.
- Update to Version 1.1.22
  * No fenv header usage if software floating-point emulation is used (bug
    report: NaN test failed on Debian armel).
- Implement single-spec version.
* Sun Oct 30 2016 jengelh@inai.de
- Update descriptions. Drop authorship and irrelevant future notes.
* Fri Oct 28 2016 toddrme2178@gmail.com
- Update to version 1.1.21:
  * Appropiate use of std namespace
- Update to version 1.1.20:
  * New version number due to PyPI upload error.
- Update to version 1.1.19:
  * Fixed unit tests. They can be run with "python setup.py test" now.
- Update to version 1.1.18:
  * Fixed missing NumPy header include path.
- Update to version 1.1.17:
  * Resolved MSVC compiler warnings.
- Update to version 1.1.16:
  * Support for large distance matrices (more than 2^31 entries, R's long
    vector support since version 3.0.0).
- Update to version 1.1.15:
  * Fixed the unit test to work with old and new R versions (see the changes
    in stats::hclust in R 3.1.0).
- Update to version 1.1.14:
  * Updated the DESCRIPTION file according to CRAN rules.
  * Renamed the "ward" method for dissimilarity input to "ward.D" in the R
    interface and created a new method "ward.D2", following changes in R's
    hclust package.
* Fri Nov 28 2014 toddrme2178@gmail.com
- Initial version
